@@ -98,79 +98,6 @@ foo_gbif <- function(sources, query, limit, start, geometry, has_coords,
   }
 }
 
-#' @noRd
-foo_bison <- function(sources, query, limit, start, geometry, date, 
-  callopts, opts) {
-
-  if (any(grepl("bison", sources))) {
-    opts <- limit_alias(opts, "bison", geometry)
-    if (class(query) %in% c("ids","tsn")) {
-      if (class(query) %in% "ids") {
-        opts$TSNs <- query$itis
-      } else {
-        opts$TSNs <- query
-      }
-      if (!is.null(date)) opts$eventDate <- date
-      bisonfxn <- "bison_solr"
-    } else {
-      if (is.null(geometry)) {
-        opts$ITISscientificName <- query
-        if (!is.null(date)) opts$eventDate <- date
-        bisonfxn <- "bison_solr"
-      } else {
-        opts$species <- query
-        bisonfxn <- "bison"
-      }
-    }
-
-    time <- now()
-    opts$verbose <- FALSE
-
-    if (bisonfxn == "bison") {
-      if (!'count' %in% names(opts)) opts$count <- limit
-      opts$config <- callopts
-    } else {
-      if (!'rows' %in% names(opts)) opts$rows <- limit
-      opts$callopts <- callopts
-    }
-    if (!'start' %in% names(opts)) opts$start <- start
-
-    if (!is.null(geometry)) {
-      opts$aoi <- if (grepl('POLYGON', paste(as.character(geometry),
-                                             collapse = " "))) {
-        geometry
-      } else {
-        bbox2wkt(bbox = geometry)
-      }
-    }
-    out <- tryCatch(do.call(eval(parse(text = bisonfxn)), opts),
-                    error = function(e) e)
-    if (is.null(out$points) || inherits(out, "simpleError")) {
-      throw_error("bison", 
-        sprintf("No records returned in Bison for %s", query))
-      throw_error("bison", out$message)
-      emptylist(opts, out$message)
-    } else{
-      dat <- out$points
-      dat$prov <- rep("bison", nrow(dat))
-      if (bisonfxn == "bison_solr") {
-        dat <- rename(dat, c('scientificName' = 'name'))
-      }
-      dat <- stand_latlon(dat)
-      dat <- add_latlong_if_missing(dat)
-      dat <- stand_dates(dat, "bison")
-      found <- if (bisonfxn == "bison_solr") {
-        out$num_found
-      } else {
-        out$summary$total
-      }
-      list(time = time, found = found, data = as_tibble(dat), opts = opts)
-    }
-  } else {
-    emptylist(opts)
-  }
-}
-
 #' @noRd
 foo_inat <- function(sources, query, limit, page, geometry, has_coords,
                      date, callopts, opts) {
