@@ -3,7 +3,8 @@ invisible(vcr::vcr_configure(
   dir = "../fixtures",
   filter_sensitive_data = list(
     "<<ebird_api_key>>" = Sys.getenv("EBIRD_KEY")
-  )
+  ),
+  json_pretty = TRUE
 ))
 
 sw <- suppressWarnings
